pub const LEVEL_WIDTH: usize = 50;
pub const LEVEL_HEIGHT: usize = 25;

#[derive(Copy, Clone, Debug, PartialEq)]
pub enum LevelElement {
    Wall,
    Floor,
    StairDown,
    StairUp,
}

#[derive(Copy, Clone, Debug, PartialEq)]
pub enum RoomType {
    Start,
    End,
    StairUp,
    StairDown,
    BasicRoom,
    EmptyRoom,
}

#[derive(Copy, Clone, Debug, PartialEq)]
pub struct Level {
    pub(crate) structure: [[LevelElement; LEVEL_HEIGHT]; LEVEL_WIDTH],
    pub(crate) start_x: usize,
    pub(crate) start_y: usize,
}

impl Level {
    pub fn new() -> Level {
        let mut s = [[LevelElement::Wall; LEVEL_HEIGHT]; LEVEL_WIDTH];
        Level {
            structure: s,
            start_x: 1,
            start_y: 1,
        }
    }
    pub fn get_element(&self, x: i16, y: i16) -> Option<LevelElement> {
        if x < 0 || y < 0 {
            return None;
        }
        if x >= LEVEL_WIDTH as i16 || y >= LEVEL_HEIGHT as i16 {
            return None;
        }
        Some(self.structure[x as usize][y as usize])
    }
}

#[test]
fn test_get_element() {
    let l = Level::new();
    assert_eq!(l.get_element(0, 0).unwrap(), LevelElement::Wall);
    assert_eq!(l.get_element(4, 4).unwrap(), LevelElement::StairDown);
    assert_eq!(l.get_element(49, 24).unwrap(), LevelElement::Wall);
    assert_eq!(l.get_element(50, 25), None);
}
